@@ -58,7 +58,8 @@ class document(object):
   title = property(_get_title, _set_title, None, 'Document title.')
 
   def __enter__(self):
-    return self._entry.__enter__()
+    self._entry.__enter__()
+    return self
 
   def __exit__(self, *args):
     return self._entry.__exit__(*args)
