@@ -380,14 +380,16 @@ class pyy_tag(object):
     return (attribute, value)
 
 
-def attr(**kwargs):
+def attr(*args, **kwargs):
   '''
   Set attributes on the current active tag context
   '''
   ctx = pyy_tag._with_contexts[_get_thread_context()]
   if ctx and ctx[-1]:
-    for attr, value in kwargs.items():
-      ctx[-1].tag.set_attribute(*pyy_tag.clean_pair(attr, value))
+    dicts = args + (kwargs,)
+    for d in dicts:
+      for attr, value in d.items():
+        ctx[-1].tag.set_attribute(*pyy_tag.clean_pair(attr, value))
   else:
     raise ValueError('not in a tag context')
 
